@@ -25,6 +25,7 @@ from ..tree import Tree, TreeConfig
 from ..kanban import Kanban, KanbanConfig
 from ..cardflow import CardFlow, CardFlowConfig
 from ..cardpanel import CardPanel, CardPanelConfig
+from ..chat import Chat, ChatConfig
 
 
 TLayout = TypeVar("TLayout", bound="Layout")
@@ -167,6 +168,11 @@ class Layout(object, metaclass=LoadUICaller):
         cardpanel_widget = CardPanel(config=cardpanel_config, container=self.layout.getCell(id))
         return cardpanel_widget
     
+    def add_chat(self, id: str, chat_config: ChatConfig = None) -> Chat:
+        """Adds a Chat widget into a Layout cell."""
+        chat_widget = Chat(config=chat_config, container=self.layout.getCell(id))
+        return chat_widget
+    
     def add_ribbon(self, id: str, ribbon_config: RibbonConfig = None) -> Any:
         """Adds a Ribbon widget into a Layout cell."""
         ribbon_widget = Ribbon(config=ribbon_config)
